{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "alpine:3.16.1",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "$(inputs.replicate_name + \"_mpileups.txt\")",
            "baseCommand": "awk",
            "arguments": [
                "{if($3!=\"N\" && $3!=\"n\") print $0}"
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": null,
                    "id": "#filter_unknown_ref_base.cwl/replicate_name"
                },
                {
                    "type": "File",
                    "id": "#filter_unknown_ref_base.cwl/text"
                }
            ],
            "id": "#filter_unknown_ref_base.cwl",
            "stdin": "$(inputs.text.path)",
            "outputs": [
                {
                    "type": "File",
                    "id": "#filter_unknown_ref_base.cwl/filtered_pileup_file",
                    "outputBinding": {
                        "glob": "$(inputs.replicate_name + \"_mpileups.txt\")"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "python:3.9",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "parse-pileup-no-vcf.py",
                            "entry": "#!/usr/bin/env python\n# =========================================================================\n# This is OPEN SOURCE SOFTWARE governed by the Gnu General Public\n# License (GPL) version 3, as described at www.opensource.org.\n# Copyright (C)2017 William H. Majoros (martiandna@gmail.com).\n#\n# Adaptation by Alejandro Barrera (aebmad@gmail.com)\n# Further Adaptation by Thomas Cowart (tc325@duke.edu)\n# =========================================================================\nimport os\nimport re\nimport sys\nfrom collections import Counter\n\nACGT = [\"A\", \"C\", \"G\", \"T\"]\n\n\ndef programName():\n    return os.path.basename(sys.argv[0])\n\n\ndef removeIndels(bases):\n    while match := re.search(\"(\\S*)[+-](\\d+)(\\S*)\", bases):\n        left = match[1]\n        indelLen = int(match[2])\n        right = match[3]\n        bases = f\"{left}{right[indelLen:]}\"\n\n    bases = re.sub(\"\\^.\", \"\", bases)\n    bases = re.sub(\"\\$\", \"\", bases)\n\n    return bases\n\n\ndef parseBases(bases):\n    return Counter(removeIndels(bases).upper())\n\n\n# =========================================================================\n# main()\n# =========================================================================\n\nif len(sys.argv) == 1:\n    pileup = sys.stdin\nelif len(sys.argv) == 2:\n    pileup = open(sys.argv[1], \"rt\")\nelse:\n    exit(f\"{programName()} [pileup file]\\n\")\n\n# Process the pileup file\nfor line in pileup:\n    fields = line.split()\n    if len(fields) != 6:\n        continue\n    (chrom, pos, ref, total, seq, _qual) = fields\n    seq = seq.upper()\n    pos = int(pos)\n    ref = ref.upper()\n    variantID = f\"{chrom}@{pos}\"\n    for special_character in [\".\", \",\"]:\n        seq = seq.replace(special_character, ref)\n    counts = parseBases(seq)\n    counts_str = \"\\t\".join([str(counts[base]) for base in ACGT])\n    print(variantID, chrom, pos, ACGT.index(ref) + 1, counts_str, sep=\"\\t\")\n"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "$(inputs.replicate_name + \"_parsed_mpileups.txt\")",
            "baseCommand": "python",
            "arguments": [
                "parse-pileup-no-vcf.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#parse_pileup.cwl/filtered_pileup"
                },
                {
                    "type": "string",
                    "inputBinding": null,
                    "id": "#parse_pileup.cwl/replicate_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#parse_pileup.cwl/parsed_filtered_pileup",
                    "outputBinding": {
                        "glob": "$(inputs.replicate_name + \"_parsed_mpileups.txt\")"
                    }
                }
            ],
            "id": "#parse_pileup.cwl",
            "stdin": "$(inputs.filtered_pileup.path)"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#pileups_workflow.cwl/alignments"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".fai",
                            "required": null
                        }
                    ],
                    "id": "#pileups_workflow.cwl/genome_file"
                },
                {
                    "type": "File",
                    "id": "#pileups_workflow.cwl/locations"
                },
                {
                    "type": "int",
                    "id": "#pileups_workflow.cwl/mpileup_depth"
                },
                {
                    "type": "string",
                    "id": "#pileups_workflow.cwl/replicate_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#pileups_workflow.cwl/ref_counts/ref_count_file",
                    "id": "#pileups_workflow.cwl/ref_count_file"
                }
            ],
            "steps": [
                {
                    "run": "#filter_unknown_ref_base.cwl",
                    "in": [
                        {
                            "source": "#pileups_workflow.cwl/replicate_name",
                            "id": "#pileups_workflow.cwl/filter_unknown_ref_base/replicate_name"
                        },
                        {
                            "source": "#pileups_workflow.cwl/samtools/pileups",
                            "id": "#pileups_workflow.cwl/filter_unknown_ref_base/text"
                        }
                    ],
                    "out": [
                        "#pileups_workflow.cwl/filter_unknown_ref_base/filtered_pileup_file"
                    ],
                    "id": "#pileups_workflow.cwl/filter_unknown_ref_base"
                },
                {
                    "run": "#parse_pileup.cwl",
                    "in": [
                        {
                            "source": "#pileups_workflow.cwl/filter_unknown_ref_base/filtered_pileup_file",
                            "id": "#pileups_workflow.cwl/parse_pileup/filtered_pileup"
                        },
                        {
                            "source": "#pileups_workflow.cwl/replicate_name",
                            "id": "#pileups_workflow.cwl/parse_pileup/replicate_name"
                        }
                    ],
                    "out": [
                        "#pileups_workflow.cwl/parse_pileup/parsed_filtered_pileup"
                    ],
                    "id": "#pileups_workflow.cwl/parse_pileup"
                },
                {
                    "run": "#ref_counts.cwl",
                    "in": [
                        {
                            "source": "#pileups_workflow.cwl/parse_pileup/parsed_filtered_pileup",
                            "id": "#pileups_workflow.cwl/ref_counts/parsed_pileup"
                        },
                        {
                            "source": "#pileups_workflow.cwl/replicate_name",
                            "id": "#pileups_workflow.cwl/ref_counts/replicate_name"
                        }
                    ],
                    "out": [
                        "#pileups_workflow.cwl/ref_counts/ref_count_file"
                    ],
                    "id": "#pileups_workflow.cwl/ref_counts"
                },
                {
                    "run": "#samtools_mpileup.cwl",
                    "in": [
                        {
                            "source": "#pileups_workflow.cwl/alignments",
                            "id": "#pileups_workflow.cwl/samtools/alignments"
                        },
                        {
                            "source": "#pileups_workflow.cwl/mpileup_depth",
                            "id": "#pileups_workflow.cwl/samtools/depth"
                        },
                        {
                            "source": "#pileups_workflow.cwl/genome_file",
                            "id": "#pileups_workflow.cwl/samtools/genome_file"
                        },
                        {
                            "source": "#pileups_workflow.cwl/locations",
                            "id": "#pileups_workflow.cwl/samtools/locations"
                        }
                    ],
                    "out": [
                        "#pileups_workflow.cwl/samtools/pileups"
                    ],
                    "id": "#pileups_workflow.cwl/samtools"
                }
            ],
            "id": "#pileups_workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ghcr.io/reddylab/bird-workflow-python:main",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "ref_counts.py",
                            "entry": "import os\nimport sys\n\nimport pandas as pd\n\n\ndef programName():\n    return os.path.basename(sys.argv[0])\n\n\nif len(sys.argv) == 1:\n    pileup = sys.stdin\nelif len(sys.argv) == 2:\n    pileup = open(sys.argv[1], \"rt\")\nelse:\n    exit(f\"{programName()} [pileup file]\\n\")\n\n# THE COLUMNS IN THE MPILEUP OUTPUT ARE AS FOLLOWS\n#    ID\n#    CHR\n#    1-BASED POSITION\n#    REF BASE (1=A,2=C,3=G,4=T) THIS IS FOR EASE OF DOWNSTREAM PROCESSING\n#    \"A\" COUNT\n#    \"C\" COUNT\n#    \"G\" COUNT\n#    \"T\" COUNT\nreads = pd.read_csv(\n    pileup,\n    sep=\"\\t\",\n    header=0,\n    quotechar='\"',\n    names=[\n        \"id\",\n        \"chr\",\n        \"position\",\n        \"ref_base\",\n        \"a_count\",\n        \"c_count\",\n        \"g_count\",\n        \"t_count\",\n    ],\n)\n\n\ndef ref_alt_count(row):\n    if row[\"ref_base\"] == 1:\n        ref_count = row[\"a_count\"]\n        alt_count = row[[\"c_count\", \"g_count\", \"t_count\"]].max()\n    elif row[\"ref_base\"] == 2:\n        ref_count = row[\"c_count\"]\n        alt_count = row[[\"a_count\", \"g_count\", \"t_count\"]].max()\n    elif row[\"ref_base\"] == 3:\n        ref_count = row[\"g_count\"]\n        alt_count = row[[\"a_count\", \"c_count\", \"t_count\"]].max()\n    elif row[\"ref_base\"] == 4:\n        ref_count = row[\"t_count\"]\n        alt_count = row[[\"a_count\", \"c_count\", \"g_count\"]].max()\n\n    return row[\"id\"], ref_count, alt_count\n\n\nref_counts = reads.apply(ref_alt_count, axis=1, result_type=\"expand\")\nref_counts.to_csv(sys.stdout, sep=\"\\t\", index=False, header=None)\n"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "$(inputs.replicate_name + \"_ref_counts.txt\")",
            "baseCommand": "python",
            "arguments": [
                "ref_counts.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#ref_counts.cwl/parsed_pileup"
                },
                {
                    "type": "string",
                    "inputBinding": null,
                    "id": "#ref_counts.cwl/replicate_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#ref_counts.cwl/ref_count_file",
                    "outputBinding": {
                        "glob": "$(inputs.replicate_name + \"_ref_counts.txt\")"
                    }
                }
            ],
            "id": "#ref_counts.cwl",
            "stdin": "$(inputs.parsed_pileup.path)"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "stdout": "pileup.txt",
            "baseCommand": "samtools",
            "arguments": [
                "mpileup"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#samtools_mpileup.cwl/alignments"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-d"
                    },
                    "id": "#samtools_mpileup.cwl/depth"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".fai",
                            "required": null
                        }
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-f"
                    },
                    "id": "#samtools_mpileup.cwl/genome_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-l"
                    },
                    "id": "#samtools_mpileup.cwl/locations"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_mpileup.cwl/pileups",
                    "outputBinding": {
                        "glob": "pileup.txt"
                    }
                }
            ],
            "id": "#samtools_mpileup.cwl"
        },
        {
            "class": "Workflow",
            "doc": "Combines read counts (generated by the 01_mpileups workflow) from multiple files into one file.\n",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#combine_counts.cwl/replicates"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#combine_counts.cwl/combine_counts/merged_counts",
                    "id": "#combine_counts.cwl/merged_counts"
                }
            ],
            "steps": [
                {
                    "run": "#combine_counts.cwl_2",
                    "in": [
                        {
                            "source": "#combine_counts.cwl/replicate_split/input_replicates",
                            "id": "#combine_counts.cwl/combine_counts/input_replicates"
                        },
                        {
                            "source": "#combine_counts.cwl/replicate_split/output_replicates",
                            "id": "#combine_counts.cwl/combine_counts/output_replicates"
                        }
                    ],
                    "out": [
                        "#combine_counts.cwl/combine_counts/merged_counts"
                    ],
                    "id": "#combine_counts.cwl/combine_counts"
                },
                {
                    "run": "#replicate_split.cwl",
                    "in": [
                        {
                            "source": "#combine_counts.cwl/replicates",
                            "id": "#combine_counts.cwl/replicate_split/replicates"
                        }
                    ],
                    "out": [
                        "#combine_counts.cwl/replicate_split/input_replicates",
                        "#combine_counts.cwl/replicate_split/output_replicates"
                    ],
                    "id": "#combine_counts.cwl/replicate_split"
                }
            ],
            "id": "#combine_counts.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Combines read counts (generated by the 01_mpileups workflow) from multiple files into one file.\n",
            "hints": [
                {
                    "dockerPull": "ghcr.io/reddylab/bird-workflow-python:main",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "combine_counts.py",
                            "entry": "import argparse\nimport os\nimport sys\n\nimport pandas as pd\n\n\ndef read_csvs(count_files):\n    for file_name in count_files:\n        yield pd.read_csv(\n            file_name,\n            sep=\"\\t\",\n            index_col=0,\n            names=[\n                os.path.basename(file_name).replace(\"_counts.txt\", \"\"),\n                os.path.basename(file_name).replace(\"ref_counts.txt\", \"alt\"),\n            ],\n        )\n\n\ndef run(args):\n    inputs = sorted(args.inputs)\n    outputs = sorted(args.outputs)\n\n    df = pd.concat(read_csvs(inputs + outputs), axis=1).fillna(0).astype(int)\n\n    # Filter out low count sites\n    df = df[df.agg(\"sum\", axis=1) > 0]\n\n    df.insert(0, \"input_count\", len(inputs))\n    df.insert(len(inputs) * 2 + 1, \"output_count\", len(outputs))\n\n    df.to_csv(sys.stdout, sep=\"\\t\", header=False)\n\n\nif __name__ == \"__main__\":\n    parser = argparse.ArgumentParser(description=\"Merge counts for BIRD processing\")\n    parser.add_argument(\"--inputs\", \"-i\", nargs=\"+\", help=\"Input replicate file names\")\n    parser.add_argument(\n        \"--outputs\", \"-o\", nargs=\"+\", help=\"Output replicate file names\"\n    )\n\n    args = parser.parse_args()\n    run(args)\n"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "stdout": "merged_counts_for_bird_no_header.txt",
            "baseCommand": "python",
            "arguments": [
                "combine_counts.py"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-i"
                    },
                    "id": "#combine_counts.cwl_2/input_replicates"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-o"
                    },
                    "id": "#combine_counts.cwl_2/output_replicates"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#combine_counts.cwl_2/merged_counts",
                    "outputBinding": {
                        "glob": "merged_counts_for_bird_no_header.txt"
                    }
                }
            ],
            "id": "#combine_counts.cwl_2"
        },
        {
            "class": "ExpressionTool",
            "doc": "Groups replicate into input and output replicates\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#replicate_split.cwl/replicates"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#replicate_split.cwl/input_replicates"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#replicate_split.cwl/output_replicates"
                }
            ],
            "expression": "${ return {\n  \"input_replicates\": inputs.replicates.filter(function(x) { return x.basename.startsWith(\"Input\")}),\n  \"output_replicates\": inputs.replicates.filter(function(x) { return x.basename.startsWith(\"Output\")})\n}}\n",
            "id": "#replicate_split.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Compute the parameters needed to split the BIRD work up\n",
            "hints": [
                {
                    "dockerPull": "python:3.9",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "bird_scatter.py",
                            "entry": "import json\nimport sys\n\nSTEP = 500\n\nif len(sys.argv) != 2:\n    exit(f\"Usage: {sys.argv[0]} <count>\")\n\ncount = int(sys.argv[1])\n\noutput = {\n    \"names\": [],\n    \"indexes\": [],\n    \"starts\": [],\n    \"ends\": []\n}\n\nfor i, start in enumerate(range(0, count, STEP), start=1):\n    output[\"names\"].append(\"sczps_no_peaks\")\n    output[\"indexes\"].append(i)\n    output[\"starts\"].append(start)\n    output[\"ends\"].append(min(start + STEP, count) - 1)\nwith open(\"cwl.output.json\", \"w\") as output_file:\n    json.dump(output, output_file)\n"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                "bird_scatter.py"
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bird_scatter.cwl/bird_counts"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "id": "#bird_scatter.cwl/ends"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "id": "#bird_scatter.cwl/indexes"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#bird_scatter.cwl/names"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "id": "#bird_scatter.cwl/starts"
                }
            ],
            "id": "#bird_scatter.cwl"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#bird_scatter_values.cwl/merged_counts"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "outputSource": "#bird_scatter_values.cwl/bird_scatter/ends",
                    "id": "#bird_scatter_values.cwl/ends"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "outputSource": "#bird_scatter_values.cwl/bird_scatter/indexes",
                    "id": "#bird_scatter_values.cwl/indexes"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "outputSource": "#bird_scatter_values.cwl/bird_scatter/names",
                    "id": "#bird_scatter_values.cwl/names"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "outputSource": "#bird_scatter_values.cwl/bird_scatter/starts",
                    "id": "#bird_scatter_values.cwl/starts"
                }
            ],
            "steps": [
                {
                    "run": "#bird_scatter.cwl",
                    "in": [
                        {
                            "source": "#bird_scatter_values.cwl/get_count/bird_counts",
                            "id": "#bird_scatter_values.cwl/bird_scatter/bird_counts"
                        }
                    ],
                    "out": [
                        "#bird_scatter_values.cwl/bird_scatter/names",
                        "#bird_scatter_values.cwl/bird_scatter/indexes",
                        "#bird_scatter_values.cwl/bird_scatter/starts",
                        "#bird_scatter_values.cwl/bird_scatter/ends"
                    ],
                    "id": "#bird_scatter_values.cwl/bird_scatter"
                },
                {
                    "run": "#get_count.cwl",
                    "in": [
                        {
                            "source": "#bird_scatter_values.cwl/merged_counts",
                            "id": "#bird_scatter_values.cwl/get_count/merged_counts"
                        }
                    ],
                    "out": [
                        "#bird_scatter_values.cwl/get_count/bird_counts"
                    ],
                    "id": "#bird_scatter_values.cwl/get_count"
                }
            ],
            "id": "#bird_scatter_values.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Get the number of variants to run BIRD on\n",
            "hints": [
                {
                    "dockerPull": "alpine:3.16.1",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "count.sh",
                            "entry": "COUNT=`grep -chv -e '^$' $1`  # count the number of non-blank lines\necho \"{\\\"bird_counts\\\":$COUNT}\" > cwl.output.json"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": "sh",
            "arguments": [
                "count.sh"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#get_count.cwl/merged_counts"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "id": "#get_count.cwl/bird_counts"
                }
            ],
            "id": "#get_count.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Run BIRD on data\n",
            "hints": [
                {
                    "dockerPull": "ghcr.io/reddylab/bird-workflow-bird:main",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "$(\"sczps_no_peaks_BIRD_output_\" + inputs.number.toString().padStart(4, \"0\") + \".txt\")",
            "baseCommand": "python",
            "arguments": [
                "/bird/bird.py",
                "/bird/BIRD"
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": null,
                    "id": "#bird.cwl/end"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#bird.cwl/input_file"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#bird.cwl/mcmc_sample_count"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bird.cwl/min_effect"
                },
                {
                    "type": "string",
                    "inputBinding": null,
                    "id": "#bird.cwl/name"
                },
                {
                    "type": "int",
                    "inputBinding": null,
                    "id": "#bird.cwl/number"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5,
                        "valueFrom": "$(inputs.name + \"_stan_\" + inputs.number.toString().padStart(4, \"0\") + \".txt\")"
                    },
                    "id": "#bird.cwl/output_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 7,
                        "valueFrom": "$(inputs.start.toString() + \"-\" + inputs.end.toString())"
                    },
                    "id": "#bird.cwl/range"
                },
                {
                    "type": "int",
                    "inputBinding": null,
                    "id": "#bird.cwl/start"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.name + \"_stan_\" + inputs.number.toString().padStart(4, \"0\") + \".txt\")"
                    },
                    "id": "#bird.cwl/bird_output"
                },
                {
                    "type": "File",
                    "id": "#bird.cwl/logged_output",
                    "outputBinding": {
                        "glob": "$(\"sczps_no_peaks_BIRD_output_\" + inputs.number.toString().padStart(4, \"0\") + \".txt\")"
                    }
                }
            ],
            "id": "#bird.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/alignment_sets"
                },
                {
                    "type": "string",
                    "id": "#main/bird_output_file"
                },
                {
                    "type": "string",
                    "id": "#main/bird_output_prefix"
                },
                {
                    "type": "string",
                    "id": "#main/bird_range"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".fai",
                            "required": null
                        }
                    ],
                    "id": "#main/genome_file"
                },
                {
                    "type": "File",
                    "id": "#main/locations"
                },
                {
                    "type": "int",
                    "id": "#main/mcmc_sample_count"
                },
                {
                    "type": "float",
                    "id": "#main/min_effect"
                },
                {
                    "type": "int",
                    "id": "#main/mpileup_depth"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/replicate_names"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bird/bird_output",
                    "id": "#main/bird_output"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bird/logged_output",
                    "id": "#main/logged_output"
                }
            ],
            "steps": [
                {
                    "run": "#bird.cwl",
                    "scatter": [
                        "#main/bird/number",
                        "#main/bird/start",
                        "#main/bird/end"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/birdScatterValues/ends",
                            "id": "#main/bird/end"
                        },
                        {
                            "source": "#main/combineCounts/merged_counts",
                            "id": "#main/bird/input_file"
                        },
                        {
                            "source": "#main/mcmc_sample_count",
                            "id": "#main/bird/mcmc_sample_count"
                        },
                        {
                            "source": "#main/min_effect",
                            "id": "#main/bird/min_effect"
                        },
                        {
                            "source": "#main/bird_output_prefix",
                            "id": "#main/bird/name"
                        },
                        {
                            "source": "#main/birdScatterValues/indexes",
                            "id": "#main/bird/number"
                        },
                        {
                            "source": "#main/bird_output_file",
                            "id": "#main/bird/output_file"
                        },
                        {
                            "source": "#main/bird_range",
                            "id": "#main/bird/range"
                        },
                        {
                            "source": "#main/birdScatterValues/starts",
                            "id": "#main/bird/start"
                        }
                    ],
                    "out": [
                        "#main/bird/logged_output",
                        "#main/bird/bird_output"
                    ],
                    "id": "#main/bird"
                },
                {
                    "run": "#bird_scatter_values.cwl",
                    "in": [
                        {
                            "source": "#main/combineCounts/merged_counts",
                            "id": "#main/birdScatterValues/merged_counts"
                        }
                    ],
                    "out": [
                        "#main/birdScatterValues/names",
                        "#main/birdScatterValues/indexes",
                        "#main/birdScatterValues/starts",
                        "#main/birdScatterValues/ends"
                    ],
                    "id": "#main/birdScatterValues"
                },
                {
                    "run": "#combine_counts.cwl",
                    "in": [
                        {
                            "source": "#main/mpileups/ref_count_file",
                            "id": "#main/combineCounts/replicates"
                        }
                    ],
                    "out": [
                        "#main/combineCounts/merged_counts"
                    ],
                    "id": "#main/combineCounts"
                },
                {
                    "run": "#pileups_workflow.cwl",
                    "scatter": [
                        "#main/mpileups/replicate_name",
                        "#main/mpileups/alignments"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/alignment_sets",
                            "id": "#main/mpileups/alignments"
                        },
                        {
                            "source": "#main/genome_file",
                            "id": "#main/mpileups/genome_file"
                        },
                        {
                            "source": "#main/locations",
                            "id": "#main/mpileups/locations"
                        },
                        {
                            "source": "#main/mpileup_depth",
                            "id": "#main/mpileups/mpileup_depth"
                        },
                        {
                            "source": "#main/replicate_names",
                            "id": "#main/mpileups/replicate_name"
                        }
                    ],
                    "out": [
                        "#main/mpileups/ref_count_file"
                    ],
                    "id": "#main/mpileups"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.2"
}
